@@ -66,8 +66,8 @@ def main(preset=None,url=None,new=None):
 		cmd_options = ["--" + k + " " + options[k] for k in options]
 		cmd_flags = ["--" + k for k in flags]
 
-		cmd = "[ytd] Issuing command: " + processname + " " + " ".join(cmd_options) + " " + " ".join(cmd_flags) + " " + url
-		print(cmd)
+		cmd = processname + " " + " ".join(cmd_options) + " " + " ".join(cmd_flags) + " " + url
+		print("[ytd] Issuing command: " + cmd)
 		os.system(cmd)
 
 	elif new is not None:
